#!/bin/bash

#
# Specify working directory
#$ -wd /scratch2/$USER/SimData/UrQMD/TMP
# Tell SGE that we will work in the woeking directory
#$ -cwd
# Specify job name
#$ -N run_sim_urqmd
# Specify SGE queue
#$ -q all.q
# Set hard time limit. If it is exceeded, SGE shuts the job
#$ -l h_rt=8:00:00
# Set soft time limit - set up the same as a hard limit
#$ -l s_rt=8:00:00
# Specify job array range (how many jobs will be created
#$ -t 1-200
#
# Specify directory where output and error logs from SGE will be stored
#$ -o /scratch2/$USER/SimData/UrQMD/TMP
#$ -e /scratch2/$USER/SimData/UrQMD/TMP
#

# ${JOB_ID} - Id of the job array (one for all jobs)
# ${SGE_TASK_ID} - id of the element of the job array
# SGE option "-t 1-N" tells array range. It will create an array
#     of N jobs with ${JOB_ID}_1, ${JOB_ID}_2, ..., ${JOB_ID}_N

#Main directory
export MAIN_DIR=/scratch2/${USER}/SimData/UrQMD
export FILE_LIST=/scratch2/parfenov/SimData/UrQMD/scripts/mcini_bibi_9gev_urqmd.list
CURRENT_FILE=`sed "${SGE_TASK_ID}q;d" ${FILE_LIST}`

export OUT_DIR1=`dirname ${CURRENT_FILE}`
export OUT_DIR=`sed "s|files|files_mcpico|g" <<< ${OUT_DIR1}`
export OUT_LOG=`sed "s|files|log_mcpico|g" <<< ${OUT_DIR1}`
export OUT_FILE1=`basename ${CURRENT_FILE}`
export OUT_FILE2=`sed "s|mcini|mcpico|g" <<< ${OUT_FILE1}`
export OUT_LOG1=`sed "s|.root|.log|g" <<< ${OUT_FILE2}`
export OUT_FILE=${OUT_DIR}/${OUT_FILE2}
export LOG=${OUT_LOG}/${OUT_LOG1}

mkdir -p $OUT_DIR
mkdir -p $OUT_LOG

export START_DIR=${PWD}
export MCINI_DIR=/scratch2/parfenov/Soft/mcini
export CONVERTER_MACRO=${MCINI_DIR}/macro/convert.C

source /opt/fairsoft/bmn/may18p1/bin/thisroot.sh &>> $LOG
source ${MCINI_DIR}/macro/config.sh &>> $LOG

echo "---------------" &>> $LOG
echo "Run mcini2mcpico converter..." &>> $LOG
# root -l -b -q $CONVERTER_MACRO'("'unigen.root'","'${OUT_FILE}/urqmd_${JOB_ID}_${SGE_TASK_ID}.mcpico.root'",'${ecm}',"'model'","'system'")' &>> $LOG
root -l -b -q $CONVERTER_MACRO'("'${CURRENT_FILE}'","'${OUT_FILE}'")' &>> $LOG

echo "Job is done!" &>> $LOG